@@ -1,11 +1,13 @@
 package Log::ger::Output::Screen;
 
-our $DATE = '2017-06-23'; # DATE
-our $VERSION = '0.004'; # VERSION
+our $DATE = '2017-06-30'; # DATE
+our $VERSION = '0.005'; # VERSION
 
 use strict;
 use warnings;
 
+use Log::ger::Util;
+
 my %colors = (
     1 => "\e[31m"  , # fatal, red
     2 => "\e[35m"  , # error, magenta
@@ -40,8 +42,8 @@ sub get_hooks {
             __PACKAGE__, 50,
             sub {
                 my %args = @_;
-                my $level = $args{level};
                 my $logger = sub {
+                    my $level = $args{level};
                     my $msg = $_[1];
                     if ($formatter) {
                         $msg = $formatter->($msg);
@@ -56,6 +58,27 @@ sub get_hooks {
                 };
                 [$logger];
             }],
+        create_logml_routine => [
+            __PACKAGE__, 50,
+            sub {
+                my %args = @_;
+                my $logger = sub {
+                    my $level = Log::ger::Util::numeric_level($_[1]);
+                    return if $level > $Log::ger::Current_Level;
+                    my $msg = $_[2];
+                    if ($formatter) {
+                        $msg = $formatter->($msg);
+                    }
+                    hook_before_log({ _fh=>$handle }, $msg);
+                    if ($use_color) {
+                        print $handle $colors{$level}, $msg, "\e[0m";
+                    } else {
+                        print $handle $msg;
+                    }
+                    hook_after_log({ _fh=>$handle }, $msg);
+                };
+                [$logger];
+            }],
     };
 }
 
@@ -74,7 +97,7 @@ Log::ger::Output::Screen - Output log to screen
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
